operator <= method

ValueCell<bool> operator <=(
  1. ValueCell<Duration> other
)

Returns a cell of which the value is true if this is less than or equal to other

Implementation

ValueCell<bool> operator <=(ValueCell<Duration> other) =>
    (this, other).apply((a, b) => a <= b);